import Taro, { Component } from '@tarojs/taro';
import { View, Video } from '@tarojs/components'
import './index.scss'
import Banner from '../banner'
import HelpGroupBanner from '../swiper'
import Poster from './poster'
import PoiAround from '@components/amap/PoiAround'
import Around from './Around'
import BackHomeBtn from '@components/BackHomeBtn'
import {
  addItemUv,
  addItemShareNum,
  favorProject,
  cancelFavorProject
} from '@services/item'
import { getMiniQrcode, savePoint, updatePoint } from '@services/common'
import { queryNewsList, queryHelpGroup } from '@services/news'
import { queryActivityList } from '@services/activity'
import dayjs from 'dayjs'
import 'dayjs/locale/zh-cn' // 按需加载
import ready from '@utils/ready'
import Notice from '@components/Notice'
import { getDownloadURL, getThumbnail } from '@utils/tools'
import { getPoiAround } from '@utils/amap'
import { connect } from '@tarojs/redux'
import { dispatchProjectDetail } from '@actions/project'
import getUserPhone from '@utils/getUserPhone'
import { ROLE_CODE } from '@constants/user'
const buildBg = require('@assets/buildbg.png')

@connect(
  ({ user, project }) => ({ ...user, ...project }),
  { dispatchProjectDetail }
)
export default class Index extends Component {
  config = {
    navigationBarTitleText: '项目详情',
  }

  state = {
    buildingId: null,
    isSaved: false,
    loaded: false,
    posterStatus: false,
    buildingProjectType: [],
    posterData: {},
    newsList: [],
    activityList: [],
    helpList: [],
    groupList: [],
    statusOpts: ['待定', '在建', '在售'],
    circumOpts: [],
    curTab: 'Transport',
    recordId: null,
    posterShow: 'none',
    current: 1,
    btnstate: 1,// 1显示视频 0显示图片
  }

  componentWillMount () {
    // const { id = '78c3dd489791dc1d29472fa344b08c45' } = this.$router.params
    ready.queue(() => {
      const router = Taro.getStorageSync('router')
      const id = this.$router.params.id || router.query.id
      // const id='82b54f4a1f5b981df572253792afbfa1' 
      this.setState({
        buildingId: id
      }, () => {
        this.loadDetail()
        this.loadNewsData()
        this.loadActivityData()
        this.loadHelpGroupList()

        addItemUv(id)
        // 埋点
        savePoint({
          event: 'detail',
          eventType: 'building',
          propertyName: '项目详情',
          targetId: id,
          buildingId: id,
          data: '{}'
        }).then(res => {
          this.setState({
            recordId: res.recordId
          })
          console.log('项目详情')
        })
      })
    })
  }

  componentWillUnmount () {
    const { recordId } = this.state
    recordId && updatePoint(recordId)
  }

  loadMapAround (building) {
    const [lat, lng] = (building.coordinate || '').split(',')

    if (!lat || !lng) return Promise.reject()

    return getPoiAround({ lng, lat })
  }

  loadHelpGroupList () {
    const { buildingId } = this.state
    queryHelpGroup({ buildingId: buildingId }).then(res => {
      console.log(res, "buildingId")
      const helpList = []
      const groupList = []
      res.map(item => {
        if (item.type == 1) {
          helpList.push(item)
        } else {
          groupList.push(item)
        }
      })
      this.setState({
        helpList,
        groupList
      })
    }
    )
  }

  loadDetail () {
    const { buildingId } = this.state
    const { dispatchProjectDetail } = this.props
    this.setState({
      loaded: false,
    })
    Taro.showToast({
      title: '正在加载数据',
      icon: 'loading'
    })

    dispatchProjectDetail(buildingId).then(res => {
      this.loadMapAround(res).then(data => {
        const newCircumOpts = data.map((item) => {
          const dtKey = `building${item.key}`
          const manualDt = res[dtKey] ? res[dtKey].split(',') : []

          return {
            ...item,
            manualDt,
            num: manualDt.length + item.poisData.length
          }
        })

        this.setState({
          loaded: true,
          circumOpts: newCircumOpts,
          isSaved: res.isSave
        }, () => {
          if (res.posters && res.posters.length) {
            this.setState({
              posterShow: 'flex'
            })
          }
        })

        Taro.hideToast()
      })
    })
  }

  loadActivityData () {
    const { buildingId } = this.state
    const payload = { pageSize: 999, pageNumber: 1, buildingId }
    queryActivityList(payload).then(res => {
      this.setState({
        activityList: res.list || []
      })
    })
  }

  loadNewsData () {
    const { buildingId } = this.state
    const payload = { pageSize: 2, pageNumber: 1, buildingId }
    queryNewsList(payload).then(res => {
      this.setState({
        newsList: res.records || []
      })
    })
  }

  navigateTo (url) {
    Taro.navigateTo({ url: url })
  }
  // 海报预览图
  previewImage (arr) {
    console.log('arr:' + arr)
    if (arr[0].length > 1) {
      Taro.previewImage({
        current: arr,
        urls: arr
      })
    } else {
      var previewArr = [];
      for (var i = 0; i < arr.length; i++) {
        previewArr.push(arr[i].url);
      }
      Taro.previewImage({
        current: previewArr,
        urls: previewArr
      })
    }
    savePoint({
      event: 'apartment',
      eventType: 'building',
      propertyName: '查看户型',
      data: '{}'
    }).then(res => {
      console.log('查看户型')
    })
  }

  openMap () {
    const {
      buildingName,
      address,
      coordinate = ''
    } = this.props.projectDetail

    const coord = coordinate.split(',')
    const latitude = parseFloat(coord[0])
    const longitude = parseFloat(coord[1])
    Taro.openLocation({
      latitude,
      longitude,
      name: buildingName,
      address,
      scale: 18
    })
    savePoint({
      event: 'navigation',
      eventType: 'building',
      propertyName: '查看项目地图',
      data: '{}'
    }).then(res => {
      console.log('查看项目地图')
    })
  }

  toViewAlbum () {
    const { buildingId } = this.state
    this.navigateTo(`/pages/project/album/index?id=${buildingId}`)
  }

  onViewFans () {
    const { buildingId } = this.state
    this.navigateTo('/pages/card/fans/index?type=item&id=' + buildingId)
  }

  onShareAppMessage = () => {
    const {
      projectDetail: { shareContents, buildingName, buildingId, poster },
      userInfo: { person: { personId } }
    } = this.props
    // 分享埋点
    addItemShareNum(buildingId)

    savePoint({
      event: 'share',
      eventType: 'building',
      propertyName: '项目详情分享',
      data: '{}'
    }).then(res => {
      console.log('项目详情分享')
    })

    return {
      title: shareContents[0].shareContentTitle,//分享内容
      path: `/pages/project/detail/index?id=${buildingId}&from=building_share&recommender=${personId}`,//分享地址
      imageUrl: shareContents[0].shareContentImg
    }
  }

  getPhoneNumber (e, item) {
    getUserPhone(e, (phoneNumber) => {
      const { userInfo: { person: { personId, nickname, name } } } = this.props
      Taro.navigateTo({
        url: `/pages/im/index?sendId=${personId}&sendName=${encodeURIComponent(name || nickname)}&receiverId=${item.id}&receiverName=${encodeURIComponent(item.userName)}`
      })
    })
  }

  getPosterData () {
    return new Promise(resolve => {
      const { posterData } = this.state
      if (posterData.qrcode) {
        resolve(posterData)
        return
      }
      const {
        userInfo: { person: { avatarurl, nickname, personId } },
        projectDetail: { posters, buildingId, poster, price, buildingRestaurant, createDate, buildingName, tel, buildingTag, uvList = {} }
      } = this.props
      const { total = 0 } = uvList
      const payload = {
        "scene": `id=${buildingId}&from=building_share&recommender=${personId}`,
        "page": 'pages/project/detail/index',
      }
      const _avatarurl = getDownloadURL(avatarurl, 'avatar');

      getMiniQrcode(payload).then(qrcode => {
        let data = {
          tel,
          qrcode,//小程序二维码
          nickname,//访问者名字
          avatarurl: _avatarurl,//访问者头像
          poster: posters[0].posterImg,
          price: price,
          posterDescription: posters[0].posterDescription,
          buildingName: posters[0].posterTitle,//标题
          createDate: createDate,//时间
          buildingTag: buildingTag,//标签,
          total: total//围观人数
        }
        resolve(data)
      })
    })
  }

  // 开始生成海报
  togglePosterStatus = (flag) => {
    if (flag) {
      // App.zhuge.track('生成海报')

      this.getPosterData().then(posterData => {
        const { poster, qrcode } = posterData || {}
        if (!poster || !qrcode) {
          Taro.showToast({
            title: '没有海报背景或二维码',
            icon: 'none'
          })
          return
        }

        this.setState({
          posterStatus: !!flag,
          posterData
        })
      })
    } else {
      this.setState({
        posterStatus: !!flag
      })
    }
  }

  makePhoneCall = () => {
    const { tel: phoneNumber } = this.props.projectDetail
    Taro.makePhoneCall({
      phoneNumber
    })
  }

  handleTelClick (item, e) {
    e.stopPropagation()
    Taro.makePhoneCall({
      phoneNumber: item.phone
    })
  }

  handleChatClick (item, e) {
    e.stopPropagation()
    const { userInfo: { person: { personId, nickname, name } } } = this.props
    Taro.navigateTo({
      url: `/pages/im/index?sendId=${personId}&sendName=${encodeURIComponent(name || nickname)}&receiverId=${item.id}&receiverName=${encodeURIComponent(item.userName)}`
    })
  }

  handleConsuItemClick (item) {
    Taro.navigateTo({
      url: `/pages/card/index?id=${item.id}`
    })
  }

  handleMoreClick () {
    // App.zhuge.track('查看置业顾问列表')
    Taro.navigateTo({
      url: `/pages/card/list/index?buildingId=${this.state.buildingId}`
    })
  }

  handleStopPropagation (e) {
    e.stopPropagation()
  }

  toRecomonedPage () {
    const {
      userInfo: { person: { personType } }
    } = this.props
    if (personType === ROLE_CODE['DRIFT'] || personType === ROLE_CODE['CUSTOMER']) {
      // 游客或者客户 区别是否有电话
      Taro.navigateTo({
        url: `/pages/agent/become/index`
      })
    } else {
      Taro.navigateTo({
        url: `/pages/agent/recommend/index`
      })
    }
  }

  toHome () {
    Taro.switchTab({
      url: `/pages/project/index`
    })
  }

  HandleCircumTabClick (id) {
    this.setState({
      curTab: id
    })
  }

  handleNewsMoreClick () {
    Taro.navigateTo({
      url: `/pages/news/index?buildingId=` + this.state.buildingId
    })
  }

  handNewsItemClick (id) {
    Taro.navigateTo({
      url: '/pages/news/detail/index?id=' + id
    })
  }

  handleActivityMoreClick () {
    Taro.navigateTo({
      url: `/pages/activity/index?buildingId=` + this.state.buildingId
    })
  }

  handActivityItemClick (id) {
    Taro.navigateTo({
      url: '/pages/activity/detail/index?id=' + id
    })
  }

  handlePreviewHxImage (current, urls) {
    Taro.previewImage({
      current,
      urls
    })
  }

  handleFavor () {
    const { buildingId, isSaved } = this.state
    if (isSaved) {
      cancelFavorProject(buildingId).then(res => {
        Taro.showToast({
          title: '已取消收藏'
        })
        this.setState({
          isSaved: false
        })
      })
    } else {
      favorProject(buildingId).then(res => {
        Taro.showToast({
          title: '收藏成功'
        })
        this.setState({
          isSaved: true
        })
      })
    }
    savePoint({
      event: 'save',
      eventType: 'project',
      propertyName: '项目收藏',
      data: '{}'
    }).then(res => {
      console.log('活动项目收藏')
    })
  }
  handleToolsClick () {
    Taro.navigateTo({
      url: `/pages/toolKit/index`
    })
  }
  moreFloor () {
    Taro.navigateTo({
      url: `/pages/project/floor/index`
    })
  }

  renderBottomMenu() {
    const { userInfo: { person: { personType } } } = this.props
    const { posterShow } = this.state
    return (
      <View className='bt-nav'>
        <View className="bt-nav__left">
          <Button class='bt-nav__item' style={{ display: posterShow }} onClick={() => { this.togglePosterStatus(true) }}>
            <Image src={require('@assets/news/tupian.png')} className='poster-img'></Image>
            <Text className="text">海报</Text>
          </Button>
          <Button class='bt-nav__item' open-type="share">
            <Image src={require('@assets/news/fasong.png')} className='fenxiang-img'></Image>
            <Text className="text">分享</Text>
          </Button>
          {
            personType !== ROLE_CODE['CONSULTANT'] && (
              <Button className='bt-nav__item' onClick={this.toRecomonedPage}>
                <Image src={require('@assets/news/peo.png')} className='kehutuijian-img'></Image>
                <Text className="text">推荐客户</Text>
              </Button>
            )
          }

        </View>
        <Button className='bt-nav__item  bt-nav__right' onClick={this.handleMoreClick}>
          <Text className="text">在线聊</Text>
        </Button>
        <Button className='bt-nav__item  bt-nav__right bt-nav__right2' onClick={this.makePhoneCall}>
          <Text className="iconfont icon-tel"></Text>
          <Text className="text">打电话</Text>
        </Button>
      </View>
    )
  }

  previewHouseImage (current, urls) {
    Taro.previewImage({
      current,
      urls
    })
  }

  renderBuildingProjectTypeList () {
    const { statusOpts } = this.state
    const { projectDetail: { buildingProjectType = [], status, marketStatus } } = this.props
    return (
      <Block>
        {
          buildingProjectType.length > 0 && (
            <ScrollView
              scrollX
              className='type-intro'
            >
              <View className="type-intro__list">
                {
                  buildingProjectType.map(item => (
                    <View className='type-intro__item' key={item.buildingId} style={`background: url(${getThumbnail(buildBg)}) no-repeat center;background-size: 100% 100%;`}>

                      <View >

                        {marketStatus &&
                          <Text className='item__status' className={marketStatus == '在售' ? 'item__status sale' : marketStatus == '售罄' ? 'item__status soldout' : 'item__status waitsale'}>{marketStatus}</Text>
                        }
                        {/* <Text className='type-status'>{statusOpts[status]}</Text> */}
                        {/* <Icon className="iconfont icon-jinrongxianxingge-" onClick={this.handleToolsClick}></Icon> */}
                        <View className='row' style="margin-top:0">
                          <Text className='row-label'>项目类型：</Text>
                          <Text className='row-txt black'>{item.buildingTypeName}</Text>
                        </View>
                        <View className='row'>
                          <Text className='row-label'>项目参考价格：</Text>
                          {
                            item.price ? <Text className='row-txt'>约{item.price}元/m²</Text> : <Text className='row-txt'>待定</Text>
                          }
                        </View>
                        <View className='row'>
                          <Text className='row-label'>产权：</Text>
                          <Text className='row-txt'>{item.rightsYear}年</Text>
                          <View className='row-right'>
                            <Text className='row-label'>装修：</Text>
                            <Text className='row-txt'>{item.decoration}</Text>
                          </View>
                        </View>
                      </View>
                    </View>
                  ))
                }
              </View>
            </ScrollView>
          )
        }
      </Block>
    )
  }


  renderPhotoAlbum () {
    const { projectDetail: { buildingApartment } } = this.props
    const list = buildingApartment.filter(item => item.apartmentType === 'photo')
    const imgList = list.reduce((prev, cur) => {
      prev = prev.concat(cur.buildingImgList)
      return prev
    }, [])
    return (
      <Block>
        {
          imgList.length > 0 && (
            <View className='photos__type'>
              <View className='photos__type__title'>相册</View>
              <ScrollView scrollX>
                <View className='photos__type__content'>
                  <View className='photos__type__list'>11
                    {/* <Image className='photos__img' src={getThumbnail(imgList[0].url)} mode="widthFix" onClick={this.toViewAlbum}></Image>
                    <View className='photos__img__len'>共{imgList.length}张</View> */}
                  </View>
                </View>
              </ScrollView>
            </View>
          )
        }
      </Block>
    )
  }
  rendercircum () {
    const building = {
      ...this.props.projectDetail,
      mapJson: `[{"key":"Transport","label":"交通","data":[{"id":"BV10847816","parent":[],"childtype":[],"name":"学清路(地铁站)","type":"交通设施服务;地铁站;地铁站","typecode":"150500","biz_type":[],"address":"(在建)昌平线南延线","location":"116.352106,40.015273","tel":[],"distance":"524","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B0FFJRUO15","parent":[],"childtype":[],"name":"青岩码头","type":"交通设施服务;港口码头;港口码头","typecode":"150300","biz_type":[],"address":"清河龙岗路20号(龙岗路农业银行)","location":"116.356013,40.030567","tel":[],"distance":"1271","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"BV10847815","parent":[],"childtype":[],"name":"上清桥(地铁站)","type":"交通设施服务;地铁站;地铁站","typecode":"150500","biz_type":[],"address":"(在建)昌平线南延线","location":"116.343524,40.034952","tel":[],"distance":"1788","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"BV10013467","parent":[],"childtype":[],"name":"林萃桥(地铁站)","type":"交通设施服务;地铁站;地铁站","typecode":"150500","biz_type":[],"address":"8号线","location":"116.372998,40.021906","tel":[],"distance":"1907","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"朝阳区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/04ed19f5ae5ff5316ed2c0c93fd2605f","provider":[],"title":[]}]},{"id":"BV10000769","parent":[],"childtype":[],"name":"永泰庄(地铁站)","type":"交通设施服务;地铁站;地铁站","typecode":"150500","biz_type":[],"address":"8号线","location":"116.354580,40.037728","tel":[],"distance":"2013","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/78c8541182bdd4f9135fd0bc99784032","provider":[],"title":[]}]},{"id":"BV10416642","parent":[],"childtype":[],"name":"六道口(地铁站)","type":"交通设施服务;地铁站;地铁站","typecode":"150500","biz_type":[],"address":"(在建)昌平线南延线;15号线","location":"116.352670,40.000958","tel":[],"distance":"2111","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/3391e9bc3a69642e752d6146593bcc8e","provider":[],"title":[]}]},{"id":"BV10416646","parent":[],"childtype":[],"name":"清华东路西口(地铁站)","type":"交通设施服务;地铁站;地铁站","typecode":"150500","biz_type":[],"address":"15号线","location":"116.339530,40.000673","tel":[],"distance":"2342","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/5d48d11d2040a96c2b6ebe00b910bd47","provider":[],"title":[]}]},{"id":"BV10416650","parent":[],"childtype":[],"name":"北沙滩(地铁站)","type":"交通设施服务;地铁站;地铁站","typecode":"150500","biz_type":[],"address":"15号线","location":"116.368143,40.001492","tel":[],"distance":"2525","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/e91bedd17d010da544bf8a2dbd4f7df4","provider":[],"title":[]}]},{"id":"BX10015631","parent":"BV10013468","childtype":"107","name":"西小口地铁站C东南口","type":"交通设施服务;地铁站;出入口","typecode":"150501","biz_type":[],"address":"8号线","location":"116.352471,40.046236","tel":[],"distance":"2938","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"BX10015630","parent":"BV10013468","childtype":"107","name":"西小口地铁站D西南口","type":"交通设施服务;地铁站;出入口","typecode":"150501","biz_type":[],"address":"8号线","location":"116.351462,40.046304","tel":[],"distance":"2942","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"BV10013516","parent":[],"childtype":[],"name":"上地(地铁站)","type":"交通设施服务;地铁站;地铁站","typecode":"150500","biz_type":[],"address":"13号线","location":"116.320193,40.033007","tel":[],"distance":"2988","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]}],"markers":[{"latitude":40.015273,"longitude":116.352106,"width":22,"height":32,"id":0,"name":"学清路(地铁站)","address":"(在建)昌平线南延线"},{"latitude":40.030567,"longitude":116.356013,"width":22,"height":32,"id":1,"name":"青岩码头","address":"清河龙岗路20号(龙岗路农业银行)"},{"latitude":40.034952,"longitude":116.343524,"width":22,"height":32,"id":2,"name":"上清桥(地铁站)","address":"(在建)昌平线南延线"},{"latitude":40.021906,"longitude":116.372998,"width":22,"height":32,"id":3,"name":"林萃桥(地铁站)","address":"8号线"},{"latitude":40.037728,"longitude":116.35458,"width":22,"height":32,"id":4,"name":"永泰庄(地铁站)","address":"8号线"},{"latitude":40.000958,"longitude":116.35267,"width":22,"height":32,"id":5,"name":"六道口(地铁站)","address":"(在建)昌平线南延线;15号线"},{"latitude":40.000673,"longitude":116.33953,"width":22,"height":32,"id":6,"name":"清华东路西口(地铁站)","address":"15号线"},{"latitude":40.001492,"longitude":116.368143,"width":22,"height":32,"id":7,"name":"北沙滩(地铁站)","address":"15号线"},{"latitude":40.046236,"longitude":116.352471,"width":22,"height":32,"id":8,"name":"西小口地铁站C东南口","address":"8号线"},{"latitude":40.046304,"longitude":116.351462,"width":22,"height":32,"id":9,"name":"西小口地铁站D西南口","address":"8号线"},{"latitude":40.033007,"longitude":116.320193,"width":22,"height":32,"id":10,"name":"上地(地铁站)","address":"13号线"}],"manualDt":["地铁号线","国道105"],"num":13},{"key":"Bank","label":"银行","data":[{"id":"B0FFL6D5EI","parent":[],"childtype":[],"name":"中国光大银行","type":"金融保险服务;银行;中国光大银行","typecode":"160113","biz_type":[],"address":"学清路10号院附近","location":"116.352360,40.014681","tel":[],"distance":"593","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B000A298B4","parent":[],"childtype":[],"name":"北京农商银行(八家分理处)","type":"金融保险服务;银行;北京农商银行","typecode":"160149","biz_type":[],"address":"双清路18-8号","location":"116.343480,40.015267","tel":"010-62840987;010-82413980","distance":"806","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/f8e2520a512b7f57dc9205138783b257","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/53ab7b6ba3106c892e6dfce3","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/45dc97d67f851c287ce4f7167ac7f0a8","provider":[],"title":[]}]},{"id":"B0FFI6K26H","parent":[],"childtype":[],"name":"北京银行(八家嘉园社区支行)","type":"金融保险服务;银行;北京银行","typecode":"160119","biz_type":[],"address":"月泉路","location":"116.343457,40.015281","tel":"010-62946150","distance":"806","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B000A8XHMF","parent":[],"childtype":[],"name":"中国建设银行(北京龙岗路支行)","type":"金融保险服务;银行;中国建设银行","typecode":"160106","biz_type":[],"address":"永泰庄6号院","location":"116.352713,40.030645","tel":"010-62901080;010-62905720;95533","distance":"1210","biz_ext":{"rating":"3.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/b12e9999c6dd049bc017ed1e2185fea7","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/87e08eeb64ddcd958bde6417729ec215","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/5fc2c79cd980f676b13fe6488bd2456f","provider":[],"title":[]}]},{"id":"B000A888GU","parent":"B0FFFCS4OP","childtype":"202","name":"交通银行(清河支行)","type":"金融保险服务;银行;交通银行","typecode":"160108","biz_type":[],"address":"龙岗路清景园4号楼1层","location":"116.352113,40.030749","tel":"010-52718589;95559","distance":"1216","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/2ea6433664ba33462dc9f987a9b0cf75","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/ef12dfb3b084724aed1fcc530864c431","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/d1865c5b4cb91460b057667fbfb76cde","provider":[],"title":[]}]},{"id":"B000A888GP","parent":"B0FFFCS5VE","childtype":"202","name":"北京银行(清河支行)","type":"金融保险服务;银行;北京银行","typecode":"160119","biz_type":[],"address":"清河清景园5号商业楼1层A区","location":"116.351904,40.031169","tel":"010-62990536;010-62995878;95526","distance":"1261","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/0d946ac5a624ab90a1c397fcc36c4082","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/405121fdf8d8db23254bf810b0d4a1ba","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/1038f581f9c171a8b8c69fbb611de1aa","provider":[],"title":[]}]},{"id":"B000A8876V","parent":[],"childtype":[],"name":"中国农业银行(北京龙岗路支行)","type":"金融保险服务;银行;中国农业银行","typecode":"160107","biz_type":[],"address":"龙岗路20号","location":"116.356134,40.030537","tel":"010-62991550;010-62996623","distance":"1271","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/f5d773e00e0fe17f46de29d3ad5a0f3b","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/0b7917040fa5dd5d283fe5902711eb47","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/80481d78cb482fdc75234e4e6b44c016","provider":[],"title":[]}]},{"id":"B0FFFOMJ78","parent":[],"childtype":[],"name":"中国光大银行(龙岗社区支行)","type":"金融保险服务;银行;中国光大银行","typecode":"160113","biz_type":[],"address":"龙岗路35号高巢小区","location":"116.358208,40.030800","tel":"010-51553095;95595","distance":"1371","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/40661c655193a1abaee8facfa408e019","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/1cca900b1c6f69e45a6de50aee2ff78f","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/ae68fb8ee6d461555e4f55dadcc35767","provider":[],"title":"门头照"}]},{"id":"B000A83GG8","parent":[],"childtype":[],"name":"中国邮政储蓄银行(清河镇支行)","type":"金融保险服务;银行;中国邮政储蓄银行","typecode":"160139","biz_type":[],"address":"清河三街90号","location":"116.341080,40.031063","tel":"010-62953378;010-62929688","distance":"1494","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/f834d9d6109ce5a3339b66e64b532669","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/8af6f43d199c85a78c5b0bb9462d6a5b","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/7d21e6db2796671dae020c651205dc3b","provider":[],"title":[]}]},{"id":"B000A830KJ","parent":"B0FFJ0Q2N9","childtype":"202","name":"中国邮政储蓄银行(永泰支行)","type":"金融保险服务;银行;中国邮政储蓄银行","typecode":"160139","biz_type":[],"address":"永泰中路永泰西里2号楼","location":"116.355923,40.033749","tel":[],"distance":"1605","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/9b38d688ec112eb87c6625723e9e856b","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/f4443c7b2ccb6d6934c35d281f11c9b3","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/1ab2557fad528fbb15a604d79739e0db","provider":[],"title":[]}]},{"id":"B000A478B2","parent":[],"childtype":[],"name":"中国农业银行(北京农大支行)","type":"金融保险服务;银行;中国农业银行","typecode":"160107","biz_type":[],"address":"清华东路17-16号","location":"116.352946,40.005410","tel":"010-62340440;010-82373730","distance":"1620","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/66b223f00429fbe41c883d18b20bab76","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/02a6b44152ae6041a4e98011c28ee1d7","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/31170ed6b5d6a665341aa587c369ca39","provider":[],"title":[]}]},{"id":"B0FFIS2ZDU","parent":"B0FFI2OTXV","childtype":"202","name":"中国民生银行(双清路支行)","type":"金融保险服务;银行;中国民生银行","typecode":"160112","biz_type":[],"address":"双清路77号院双清大厦1层","location":"116.340906,40.007406","tel":"010-62684317;95568","distance":"1623","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/1bdab4000a174ad2b73b836ae69c9d07","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/ec3ed41e866c4072afd5b080b2512d15","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/c160ecdf416f76852d2344d2c0d99a44","provider":[],"title":[]}]},{"id":"B0FFF3L334","parent":"B0FFHLN2EC","childtype":"201","name":"招商银行(清河支行)","type":"金融保险服务;银行;招商银行","typecode":"160109","biz_type":[],"address":"清河中街68号华润五彩城购物中心东区F1层L176","location":"116.336333,40.029682","tel":"010-82810951;010-82810977;010-82810759","distance":"1645","biz_ext":{"rating":"4.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/2d6724372c25f7f9d8b99b3f12a9871e","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/39923ec01b067257b428ed149238c24b","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/ea01ca3a5a7de32e7f9aaa2aebd5c296","provider":[],"title":[]}]},{"id":"B0FFFQUFJK","parent":"B000A9UWLK","childtype":"202","name":"中国民生银行(北京林萃社区支行)","type":"金融保险服务;银行;中国民生银行","typecode":"160112","biz_type":[],"address":"林萃路9号院京师园5号楼5-12","location":"116.370438,40.017404","tel":"010-58213790","distance":"1698","biz_ext":{"rating":"3.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"朝阳区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/6d92402359cc70532f8fab1e7bb870e5","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/4fcdf8dd9c32a864310cea8e2ce83bc4","provider":[],"title":"品牌图片"}]},{"id":"B000A7RAWS","parent":"B000A9E4Z8","childtype":"202","name":"中国工商银行(北京永泰园支行)","type":"金融保险服务;银行;中国工商银行","typecode":"160105","biz_type":[],"address":"永泰园新地标甲13号楼新地标小区(建金商场内)","location":"116.349944,40.035189","tel":"010-82750047;010-95588","distance":"1706","biz_ext":{"rating":"4.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/f9b7a2f36932aa1a8d5209f99a656d79","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/30f63710c6df0777882535ca6a0a2374","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/99b48df6c00b4820ef6b7bc0c262ebe9","provider":[],"title":[]}]},{"id":"B000A1235C","parent":[],"childtype":[],"name":"北京农商银行(北沙滩分理处)","type":"金融保险服务;银行;北京农商银行","typecode":"160149","biz_type":[],"address":"德外双泉堡甲4号","location":"116.365282,40.008822","tel":"4006696198","distance":"1744","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"朝阳区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/9746fb9a73595f149387b584ae1625e4","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/a407a5670c36c8485e4047651f7dcc4b","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/53b0df1fa310a21470ac7197","provider":[],"title":[]}]},{"id":"B000A8XGRL","parent":"B000A9E514","childtype":"202","name":"中国银行(北京小营支行)","type":"金融保险服务;银行;中国银行","typecode":"160104","biz_type":[],"address":"永泰东里41号楼1层南段","location":"116.355943,40.035040","tel":"010-62908435","distance":"1744","biz_ext":{"rating":"3.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/53a3f938031c565cb0560c4a28389cf8","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/68f4338dc3105ae80ad9ad2500a64a49","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/9ec169ed95815b9471bf08b6587e4779","provider":[],"title":[]}]},{"id":"B000A83GO5","parent":"B000A830DN","childtype":"0","name":"中国邮政储蓄银行(林业大学邮政所)","type":"金融保险服务;银行;中国邮政储蓄银行","typecode":"160139","biz_type":[],"address":"清华东路35号静淑苑路","location":"116.348895,40.004215","tel":"010-82363051;95580","distance":"1750","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/407c7e8d976d6ae7d0e5abc4d8a2b8c1","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/257c4b7733d3b3042063e7db0cdb0488","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/53bfd0bea31061620e54fd86","provider":[],"title":[]}]},{"id":"B0FFH9O6ZD","parent":[],"childtype":[],"name":"中国邮政储蓄银行(林业大学营业所)","type":"金融保险服务;银行;中国邮政储蓄银行","typecode":"160139","biz_type":[],"address":"清华东路35号静淑苑路","location":"116.348897,40.004181","tel":"95580","distance":"1754","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B0FFIGHEF0","parent":[],"childtype":[],"name":"中国邮政储蓄银行(学府树营业所)","type":"金融保险服务;银行;中国邮政储蓄银行","typecode":"160139","biz_type":[],"address":"学府树中街橡树湾4期北门旁","location":"116.334265,40.029389","tel":"95580","distance":"1761","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/d61db1d39b81fc97aefa54778f50dd49","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/53ccb338623a472d3d40f445b12ec048","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/ed23806b5f77afbbae81ba34f8891150","provider":[],"title":[]}]}],"markers":[{"latitude":40.014681,"longitude":116.35236,"width":22,"height":32,"id":0,"name":"中国光大银行","address":"学清路10号院附近"},{"latitude":40.015267,"longitude":116.34348,"width":22,"height":32,"id":1,"name":"北京农商银行(八家分理处)","address":"双清路18-8号"},{"latitude":40.015281,"longitude":116.343457,"width":22,"height":32,"id":2,"name":"北京银行(八家嘉园社区支行)","address":"月泉路"},{"latitude":40.030645,"longitude":116.352713,"width":22,"height":32,"id":3,"name":"中国建设银行(北京龙岗路支行)","address":"永泰庄6号院"},{"latitude":40.030749,"longitude":116.352113,"width":22,"height":32,"id":4,"name":"交通银行(清河支行)","address":"龙岗路清景园4号楼1层"},{"latitude":40.031169,"longitude":116.351904,"width":22,"height":32,"id":5,"name":"北京银行(清河支行)","address":"清河清景园5号商业楼1层A区"},{"latitude":40.030537,"longitude":116.356134,"width":22,"height":32,"id":6,"name":"中国农业银行(北京龙岗路支行)","address":"龙岗路20号"},{"latitude":40.0308,"longitude":116.358208,"width":22,"height":32,"id":7,"name":"中国光大银行(龙岗社区支行)","address":"龙岗路35号高巢小区"},{"latitude":40.031063,"longitude":116.34108,"width":22,"height":32,"id":8,"name":"中国邮政储蓄银行(清河镇支行)","address":"清河三街90号"},{"latitude":40.033749,"longitude":116.355923,"width":22,"height":32,"id":9,"name":"中国邮政储蓄银行(永泰支行)","address":"永泰中路永泰西里2号楼"},{"latitude":40.00541,"longitude":116.352946,"width":22,"height":32,"id":10,"name":"中国农业银行(北京农大支行)","address":"清华东路17-16号"},{"latitude":40.007406,"longitude":116.340906,"width":22,"height":32,"id":11,"name":"中国民生银行(双清路支行)","address":"双清路77号院双清大厦1层"},{"latitude":40.029682,"longitude":116.336333,"width":22,"height":32,"id":12,"name":"招商银行(清河支行)","address":"清河中街68号华润五彩城购物中心东区F1层L176"},{"latitude":40.017404,"longitude":116.370438,"width":22,"height":32,"id":13,"name":"中国民生银行(北京林萃社区支行)","address":"林萃路9号院京师园5号楼5-12"},{"latitude":40.035189,"longitude":116.349944,"width":22,"height":32,"id":14,"name":"中国工商银行(北京永泰园支行)","address":"永泰园新地标甲13号楼新地标小区(建金商场内)"},{"latitude":40.008822,"longitude":116.365282,"width":22,"height":32,"id":15,"name":"北京农商银行(北沙滩分理处)","address":"德外双泉堡甲4号"},{"latitude":40.03504,"longitude":116.355943,"width":22,"height":32,"id":16,"name":"中国银行(北京小营支行)","address":"永泰东里41号楼1层南段"},{"latitude":40.004215,"longitude":116.348895,"width":22,"height":32,"id":17,"name":"中国邮政储蓄银行(林业大学邮政所)","address":"清华东路35号静淑苑路"},{"latitude":40.004181,"longitude":116.348897,"width":22,"height":32,"id":18,"name":"中国邮政储蓄银行(林业大学营业所)","address":"清华东路35号静淑苑路"},{"latitude":40.029389,"longitude":116.334265,"width":22,"height":32,"id":19,"name":"中国邮政储蓄银行(学府树营业所)","address":"学府树中街橡树湾4期北门旁"}],"manualDt":["中国银行","招商银行","建设银行","农业银行"],"num":24},{"key":"Hospital","label":"医院","data":[{"id":"B0FFHM8VRQ","parent":"B000A83ESC","childtype":"202","name":"北京成府中医门诊部","type":"医疗保健服务;诊所;诊所","typecode":"090300","biz_type":[],"address":"学清路9号汇智大厦B座1层","location":"116.351646,40.020008","tel":[],"distance":"75","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B000AA1AWF","parent":"B000A8VSOV","childtype":"202","name":"北京嘉信科林口腔门诊部有限公司","type":"医疗保健服务;诊所;诊所","typecode":"090300","biz_type":[],"address":"学清路8号科技财富中心A座301、309","location":"116.353717,40.015752","tel":"010-82737511","distance":"522","biz_ext":{"rating":"4.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/42ec42cb60f02b53d68ce1f1ad72c195","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/83d9bb9f81cdfcc328174cd62dd12d63","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/a1f110f948b87764dc775f9dd1621acf","provider":[],"title":[]}]},{"id":"B0FFIMX84X","parent":[],"childtype":[],"name":"海淀区东升镇社区卫生服务中心","type":"医疗保健服务;综合医院;卫生院","typecode":"090102","biz_type":[],"address":"东升镇双清路西八家嘉园19号一楼","location":"116.345567,40.016183","tel":"010-62957182","distance":"605","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B0FFIMX67O","parent":[],"childtype":[],"name":"八家嘉园社区卫生服务站","type":"医疗保健服务;综合医院;卫生院","typecode":"090102","biz_type":[],"address":"东升镇双清路八家嘉园19号楼","location":"116.345389,40.016134","tel":"010-62957182","distance":"619","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B000A83EK5","parent":"B000A9EEPH","childtype":"202","name":"海淀区建清园社区卫生服务站","type":"医疗保健服务;综合医院;卫生院","typecode":"090102","biz_type":[],"address":[],"location":"116.347177,40.014923","tel":"010-62931007","distance":"630","biz_ext":{"rating":"4.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/53ab7b6ba3106c892e6dfc6f","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/29e2e00227218dfeea765ff859633e71","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/4762b461cc199e7cf2628c555bb866ae","provider":[],"title":[]}]},{"id":"B000A83EK6","parent":"B000A9EEPH","childtype":"202","name":"学院路金象大药房(学院路店)","type":"医疗保健服务;医药保健销售店;药房","typecode":"090601","biz_type":[],"address":"月泉路建清园3号楼","location":"116.346924,40.014914","tel":"010-62935491","distance":"642","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/53ab7b6ba3106c892e6dfc76","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/4c7438d2766c6e0ae59c4506967b7395","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/ae66fcfcbd8935be22244c6c1e85431d","provider":[],"title":[]}]},{"id":"B0FFHGJZ3P","parent":[],"childtype":[],"name":"北京康泽肿瘤医院","type":"医疗保健服务;专科医院;肿瘤医院","typecode":"090207","biz_type":[],"address":[],"location":"116.343220,40.020807","tel":"010-82752988","distance":"652","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B0FFG8USC3","parent":[],"childtype":[],"name":"北京泰济堂中医门诊部","type":"医疗保健服务;诊所;诊所","typecode":"090300","biz_type":[],"address":"八家嘉园小区(双清路三农服务中心)配楼(1-2层)","location":"116.343320,40.018095","tel":"010-58930996","distance":"665","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B000AA1GBN","parent":"B000A9NUO9","childtype":"202","name":"北京恒爱动物医院","type":"医疗保健服务;动物医疗场所;宠物诊所","typecode":"090701","biz_type":[],"address":"双泉堡125号院1号楼1层","location":"116.356563,40.015129","tel":"010-60603201;010-60603906","distance":"722","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/88e629c85b734fe127533012af0be5f5","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/509395042fa1ddab80bf57e91efac65e","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/8bd9931dc98cb30688926148149503b6","provider":[],"title":[]}]},{"id":"B000A84917","parent":[],"childtype":[],"name":"999急救中心","type":"医疗保健服务;急救中心;急救中心","typecode":"090400","biz_type":[],"address":"清河东路1号","location":"116.353323,40.026106","tel":"010-62922345","distance":"726","biz_ext":{"rating":"2.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"朝阳区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/84084d78fc819151692181912ba42f50","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/2f5f52879e40f2b218ab9b14e52d8f02","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/3df12955c615e4141aedcda2ecd4ca99","provider":[],"title":[]}]},{"id":"B0FFF2OPCK","parent":[],"childtype":[],"name":"北京三元集团畜牧兽医总站","type":"医疗保健服务;动物医疗场所;兽医站","typecode":"090702","biz_type":[],"address":"德胜门外清河南镇G6辅路","location":"116.357219,40.024175","tel":"010-62916203","distance":"728","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"朝阳区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFIPS98R","parent":"B000A9NUO9","childtype":"202","name":"叮当智慧药房(北沙滩店)","type":"医疗保健服务;医药保健销售店;药房","typecode":"090601","biz_type":[],"address":"双泉堡125号院-1号楼底商","location":"116.357071,40.015051","tel":"010-52434771","distance":"759","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFHD4JPP","parent":"B000A9NUO9","childtype":"202","name":"叮当快药(北沙滩店)","type":"医疗保健服务;医药保健销售店;药房","typecode":"090601","biz_type":[],"address":"双泉堡125号院1号楼1层","location":"116.357158,40.015038","tel":"010-65285488;010-52434771","distance":"765","biz_ext":{"rating":"5.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/819e2468260885964fb443cf0c6d5c52","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/66935a0345de316bf30ba323fffa5be0","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/9686a85740cbbdf643442c43c4ada0f2","provider":[],"title":[]}]},{"id":"B0FFG8URWM","parent":[],"childtype":[],"name":"德盛康大药房(第十八分店)","type":"医疗保健服务;医药保健销售店;药房","typecode":"090601","biz_type":[],"address":"学清路甲3号(四爷牛拉)","location":"116.352728,40.012864","tel":"010-62918811","distance":"797","biz_ext":{"rating":"2.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/13bb9ead05c216ada13c25929550716c","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/fcfb4d671e585930782049ee6476981b","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/f5b922092beea7ee7c3b4ae19471d5f3","provider":[],"title":[]}]},{"id":"B0FFI3JW72","parent":[],"childtype":[],"name":"中国健康医疗养老物联服务平台学知园社区健康服务站","type":"医疗保健服务;诊所;诊所","typecode":"090300","biz_type":[],"address":"银泉路南50米","location":"116.357628,40.014904","tel":[],"distance":"804","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B0FFL51O8D","parent":[],"childtype":[],"name":"建清园社区卫生服务站","type":"医疗保健服务;诊所;诊所","typecode":"090300","biz_type":[],"address":"银泉路","location":"116.357781,40.014862","tel":[],"distance":"817","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B000A9ZF76","parent":[],"childtype":[],"name":"美人鱼医疗美容门诊部","type":"医疗保健服务;专科医院;整形美容","typecode":"090201","biz_type":[],"address":"学清路16号学知轩1层106室","location":"116.353252,40.012743","tel":"010-82755662;010-60976098;15300331378","distance":"821","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/053670e8644d0196eedaefa260aa2ad2","provider":[],"title":[]}]},{"id":"B0FFH20JXO","parent":"B0FFH20K0Z","childtype":"202","name":"美人鱼医疗美容整形机构","type":"医疗保健服务;专科医院;整形美容|医疗保健服务;专科医院;口腔医院","typecode":"090201|090202","biz_type":[],"address":"学清路16号学清苑11号楼102室","location":"116.353232,40.012698","tel":"010-82755662;010-60976098;15300331378","distance":"825","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[]},{"id":"B0FFHOKPZL","parent":[],"childtype":[],"name":"辰邦智能急救站","type":"医疗保健服务;急救中心;急救中心","typecode":"090400","biz_type":[],"address":"学院路街道逸成东苑","location":"116.346540,40.012912","tel":[],"distance":"855","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"2","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/4d47c00cb07fc0758f8beadd6e9beb33","provider":[],"title":[]}]},{"id":"B0FFG8USEY","parent":[],"childtype":[],"name":"好得快大药房(八家嘉园店)","type":"医疗保健服务;医药保健销售店;药房","typecode":"090601","biz_type":[],"address":"月泉路八家嘉园配套商业23-2号","location":"116.342659,40.015299","tel":"010-62956752","distance":"859","biz_ext":{"rating":"3.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/9f83dfe948db256f9684cab62540bbed","provider":[],"title":[]}]}],"markers":[{"latitude":40.020008,"longitude":116.351646,"width":22,"height":32,"id":0,"name":"北京成府中医门诊部","address":"学清路9号汇智大厦B座1层"},{"latitude":40.015752,"longitude":116.353717,"width":22,"height":32,"id":1,"name":"北京嘉信科林口腔门诊部有限公司","address":"学清路8号科技财富中心A座301、309"},{"latitude":40.016183,"longitude":116.345567,"width":22,"height":32,"id":2,"name":"海淀区东升镇社区卫生服务中心","address":"东升镇双清路西八家嘉园19号一楼"},{"latitude":40.016134,"longitude":116.345389,"width":22,"height":32,"id":3,"name":"八家嘉园社区卫生服务站","address":"东升镇双清路八家嘉园19号楼"},{"latitude":40.014923,"longitude":116.347177,"width":22,"height":32,"id":4,"name":"海淀区建清园社区卫生服务站","address":[]},{"latitude":40.014914,"longitude":116.346924,"width":22,"height":32,"id":5,"name":"学院路金象大药房(学院路店)","address":"月泉路建清园3号楼"},{"latitude":40.020807,"longitude":116.34322,"width":22,"height":32,"id":6,"name":"北京康泽肿瘤医院","address":[]},{"latitude":40.018095,"longitude":116.34332,"width":22,"height":32,"id":7,"name":"北京泰济堂中医门诊部","address":"八家嘉园小区(双清路三农服务中心)配楼(1-2层)"},{"latitude":40.015129,"longitude":116.356563,"width":22,"height":32,"id":8,"name":"北京恒爱动物医院","address":"双泉堡125号院1号楼1层"},{"latitude":40.026106,"longitude":116.353323,"width":22,"height":32,"id":9,"name":"999急救中心","address":"清河东路1号"},{"latitude":40.024175,"longitude":116.357219,"width":22,"height":32,"id":10,"name":"北京三元集团畜牧兽医总站","address":"德胜门外清河南镇G6辅路"},{"latitude":40.015051,"longitude":116.357071,"width":22,"height":32,"id":11,"name":"叮当智慧药房(北沙滩店)","address":"双泉堡125号院-1号楼底商"},{"latitude":40.015038,"longitude":116.357158,"width":22,"height":32,"id":12,"name":"叮当快药(北沙滩店)","address":"双泉堡125号院1号楼1层"},{"latitude":40.012864,"longitude":116.352728,"width":22,"height":32,"id":13,"name":"德盛康大药房(第十八分店)","address":"学清路甲3号(四爷牛拉)"},{"latitude":40.014904,"longitude":116.357628,"width":22,"height":32,"id":14,"name":"中国健康医疗养老物联服务平台学知园社区健康服务站","address":"银泉路南50米"},{"latitude":40.014862,"longitude":116.357781,"width":22,"height":32,"id":15,"name":"建清园社区卫生服务站","address":"银泉路"},{"latitude":40.012743,"longitude":116.353252,"width":22,"height":32,"id":16,"name":"美人鱼医疗美容门诊部","address":"学清路16号学知轩1层106室"},{"latitude":40.012698,"longitude":116.353232,"width":22,"height":32,"id":17,"name":"美人鱼医疗美容整形机构","address":"学清路16号学清苑11号楼102室"},{"latitude":40.012912,"longitude":116.34654,"width":22,"height":32,"id":18,"name":"辰邦智能急救站","address":"学院路街道逸成东苑"},{"latitude":40.015299,"longitude":116.342659,"width":22,"height":32,"id":19,"name":"好得快大药房(八家嘉园店)","address":"月泉路八家嘉园配套商业23-2号"}],"manualDt":["人民医院","妇幼保健院"],"num":22},{"key":"Edu","label":"学校","data":[{"id":"B000A87DA4","parent":[],"childtype":[],"name":"宝贝双语艺术幼儿园(清河南大街)","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"清河四街东南大街8号","location":"116.349379,40.023509","tel":[],"distance":"421","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/116611c7335a042d27d0c1d6c8455d02","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/d3c181a9365365c72a2519211f322db1","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/3deb412340ddbf4b8edab8d49f92a7c4","provider":[],"title":[]}]},{"id":"B0FFHOKO6P","parent":[],"childtype":[],"name":"文华楼","type":"科教文化服务;学校;学校","typecode":"141200","biz_type":[],"address":"双清路1号","location":"116.345690,40.021301","tel":[],"distance":"461","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFLBLSYJ","parent":[],"childtype":[],"name":"清华大学附属小学清河分校","type":"科教文化服务;学校;小学","typecode":"141203","biz_type":[],"address":"清河南镇","location":"116.349352,40.024073","tel":[],"distance":"482","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B000A7Q3E4","parent":[],"childtype":[],"name":"北京培黎职业学院","type":"科教文化服务;学校;职业技术学校","typecode":"141206","biz_type":[],"address":"双清路1号","location":"116.34527,40.021034","tel":"010-62956117","distance":"486","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/02c398866ad2dc1a6db9f042c162dd28","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/c7f7e288523afd66f87f1a36b7a8db4f","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/97cf602bc2794155a0ae4a82c3c2950a","provider":[],"title":[]}]},{"id":"B0FFKQN4E5","parent":[],"childtype":[],"name":"华艺中辉教育科技集团(华艺教育学院校区)","type":"科教文化服务;学校;高等院校","typecode":"141201","biz_type":[],"address":"双清路一号培黎职业学院留创园108室","location":"116.344418,40.020722","tel":"010-52885000;15210612361","distance":"550","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"1","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/74a822ab1c6ad13c097898983f61290b","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/83c9b53ddfa4006e251da186cadcd015","provider":[],"title":[]}]},{"id":"B0FFH1324O","parent":[],"childtype":[],"name":"启迪星幼儿教育中心","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"月泉路北50米","location":"116.342500,40.015310","tel":"13341069123","distance":"869","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/a5c9d36db6011be3aa28b759519244f5","provider":[],"title":[]}]},{"id":"B0FFGMW72Q","parent":[],"childtype":[],"name":"爱育幼童","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"学清路16号学知轩大厦617(圣熙8号以北200米)","location":"116.352870,40.012210","tel":[],"distance":"871","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B000AA7WVZ","parent":[],"childtype":[],"name":"甜美乐艺术幼儿园","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"清缘西里甲6","location":"116.351582,40.027994","tel":"010-59871817;18600767396","distance":"906","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/5b68a04479c7a3b94f0a68fa975fdf5f","provider":[],"title":[]}]},{"id":"B0FFG69V11","parent":"B000AA7675","childtype":"202","name":"聪明屋幼儿园(清河路)","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"清缘西里甲7","location":"116.352193,40.028032","tel":"010-59871959","distance":"916","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/b30028b17905d382d61b52d65f3d57f5","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/a86314511e46ca5fd51f2b96d4c94500","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/539e804fa310b133764d96a2","provider":[],"title":[]}]},{"id":"B0FFFAHD3E","parent":"B0FFJSOW3X","childtype":"202","name":"生命树幼儿中心","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"林大北路清风华景园1号楼2","location":"116.347378,40.012028","tel":[],"distance":"920","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/53aa3ecfa3106c892e6da9e1","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/53aa3ecfa3106c892e6da9e3","provider":[],"title":[]}]},{"id":"B0FFFACSA6","parent":[],"childtype":[],"name":"北京市海淀区东升实验小学","type":"科教文化服务;学校;小学","typecode":"141203","biz_type":[],"address":"月泉路八家嘉园旁","location":"116.340294,40.015465","tel":"010-62937745;010-62959647","distance":"1019","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/7c30df9cd88a1dc2d4b6d2919781d9e1","provider":[],"title":[]}]},{"id":"B000A9JUGX","parent":[],"childtype":[],"name":"北京市刘诗昆音乐艺术幼儿园(清缘里东南)","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"龙岗路清缘里小区10号楼","location":"116.355684,40.028779","tel":"010-64353956","distance":"1076","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/496585179a8216c511b810341d52d950","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/5c51d2b1627edd3fc091f5830775b20f","provider":[],"title":[]}]},{"id":"B0FFGHF0J3","parent":"B0FFLDEFTZ","childtype":"202","name":"稚慧谷亲子园","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"清河嘉园东区甲1号","location":"116.346393,40.030035","tel":"010-87768865","distance":"1191","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B000A8VT9T","parent":[],"childtype":[],"name":"凯迪双语实验幼儿园(朱房路)","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"朱房路清河中街28号文苑小区","location":"116.342450,40.028786","tel":"010-62952051","distance":"1219","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/ca4ff9fc7e2b094e0b1255f0c18c5a6d","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/431f0be4fcd04c2f619488d8e86a6c3c","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/92b3c7728f2cd7f34a6bc6c0ff216f6b","provider":[],"title":[]}]},{"id":"B000A2D145","parent":[],"childtype":[],"name":"天主教北京总教区神哲学院(北京大修院)","type":"科教文化服务;学校;高等院校","typecode":"141201","biz_type":[],"address":"后八家路248号","location":"116.336352,40.020036","tel":"010-62941537","distance":"1229","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/3a9649fdcf334cb67323777a38589ca6","provider":[],"title":"外景图"},{"url":"http://store.is.autonavi.com/showpic/d909cdfa8fbc0bcb5db6d52043892dd4","provider":[],"title":"外景图"},{"url":"http://store.is.autonavi.com/showpic/c88bc2f1319c7c2d0e98bea1c1710d11","provider":[],"title":"外景图"}]},{"id":"B0FFF5EKJR","parent":"B0FFK0TPHJ","childtype":"202","name":"睿正堂教育(永泰中路)","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"清缘里中区12号楼","location":"116.357953,40.029491","tel":"010-62904546;15120001801","distance":"1233","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/75a8fcfc97b08f8b355fd1a2dfa584a5","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/5f6543fbdb5350f07a6997dd554c22f3","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/31c33c598586aceda7343bab1d53a091","provider":[],"title":[]}]},{"id":"B0FFHA2C8N","parent":[],"childtype":[],"name":"花园楼社区文明市民学校","type":"科教文化服务;学校;学校","typecode":"141200","biz_type":[],"address":"朱房路20附近","location":"116.339586,40.027463","tel":[],"distance":"1274","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B000A8XH00","parent":"B0FFGTTIM0","childtype":"202","name":"智合国学双语幼儿园","type":"科教文化服务;学校;幼儿园","typecode":"141204","biz_type":[],"address":"清河镇清缘东里3号楼","location":"116.358566,40.029723","tel":"15711127167","distance":"1281","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/59055b12bb370f2f667f2cee28d3f5a4","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/9f09ae88ee40802471ab3b2ee36283b8","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/8481c8e380e18a7288db39df77016fa0","provider":[],"title":[]}]},{"id":"B0FFJKZO7X","parent":[],"childtype":[],"name":"北京公共交通控股(集团)有限公司党校","type":"科教文化服务;学校;学校","typecode":"141200","biz_type":[],"address":"前屯路与永泰庄西路交叉口南150米","location":"116.351303,40.032106","tel":[],"distance":"1362","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFIB4PSN","parent":[],"childtype":[],"name":"华北电力大学夜大教学基地办公区","type":"科教文化服务;学校;学校","typecode":"141200","biz_type":[],"address":"前屯路与永泰庄西路交叉口南150米","location":"116.351425,40.032155","tel":[],"distance":"1368","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]}],"markers":[{"latitude":40.023509,"longitude":116.349379,"width":22,"height":32,"id":0,"name":"宝贝双语艺术幼儿园(清河南大街)","address":"清河四街东南大街8号"},{"latitude":40.021301,"longitude":116.34569,"width":22,"height":32,"id":1,"name":"文华楼","address":"双清路1号"},{"latitude":40.024073,"longitude":116.349352,"width":22,"height":32,"id":2,"name":"清华大学附属小学清河分校","address":"清河南镇"},{"latitude":40.021034,"longitude":116.34527,"width":22,"height":32,"id":3,"name":"北京培黎职业学院","address":"双清路1号"},{"latitude":40.020722,"longitude":116.344418,"width":22,"height":32,"id":4,"name":"华艺中辉教育科技集团(华艺教育学院校区)","address":"双清路一号培黎职业学院留创园108室"},{"latitude":40.01531,"longitude":116.3425,"width":22,"height":32,"id":5,"name":"启迪星幼儿教育中心","address":"月泉路北50米"},{"latitude":40.01221,"longitude":116.35287,"width":22,"height":32,"id":6,"name":"爱育幼童","address":"学清路16号学知轩大厦617(圣熙8号以北200米)"},{"latitude":40.027994,"longitude":116.351582,"width":22,"height":32,"id":7,"name":"甜美乐艺术幼儿园","address":"清缘西里甲6"},{"latitude":40.028032,"longitude":116.352193,"width":22,"height":32,"id":8,"name":"聪明屋幼儿园(清河路)","address":"清缘西里甲7"},{"latitude":40.012028,"longitude":116.347378,"width":22,"height":32,"id":9,"name":"生命树幼儿中心","address":"林大北路清风华景园1号楼2"},{"latitude":40.015465,"longitude":116.340294,"width":22,"height":32,"id":10,"name":"北京市海淀区东升实验小学","address":"月泉路八家嘉园旁"},{"latitude":40.028779,"longitude":116.355684,"width":22,"height":32,"id":11,"name":"北京市刘诗昆音乐艺术幼儿园(清缘里东南)","address":"龙岗路清缘里小区10号楼"},{"latitude":40.030035,"longitude":116.346393,"width":22,"height":32,"id":12,"name":"稚慧谷亲子园","address":"清河嘉园东区甲1号"},{"latitude":40.028786,"longitude":116.34245,"width":22,"height":32,"id":13,"name":"凯迪双语实验幼儿园(朱房路)","address":"朱房路清河中街28号文苑小区"},{"latitude":40.020036,"longitude":116.336352,"width":22,"height":32,"id":14,"name":"天主教北京总教区神哲学院(北京大修院)","address":"后八家路248号"},{"latitude":40.029491,"longitude":116.357953,"width":22,"height":32,"id":15,"name":"睿正堂教育(永泰中路)","address":"清缘里中区12号楼"},{"latitude":40.027463,"longitude":116.339586,"width":22,"height":32,"id":16,"name":"花园楼社区文明市民学校","address":"朱房路20附近"},{"latitude":40.029723,"longitude":116.358566,"width":22,"height":32,"id":17,"name":"智合国学双语幼儿园","address":"清河镇清缘东里3号楼"},{"latitude":40.032106,"longitude":116.351303,"width":22,"height":32,"id":18,"name":"北京公共交通控股(集团)有限公司党校","address":"前屯路与永泰庄西路交叉口南150米"},{"latitude":40.032155,"longitude":116.351425,"width":22,"height":32,"id":19,"name":"华北电力大学夜大教学基地办公区","address":"前屯路与永泰庄西路交叉口南150米"}],"manualDt":["朝天小学","之江中学","朝天中学"],"num":23},{"key":"Restaurant","label":"餐饮","data":[{"id":"B0FFJCBPBK","parent":[],"childtype":[],"name":"蒸点味道","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"学清路9号汇智大厦1层102-7室","location":"116.350849,40.019714","tel":"15340084707","distance":"18","biz_ext":{"rating":[],"cost":"19.00","meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/8dbf0fa5be7310ded1bbf6eecae5f278","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/c06d1a335e784c366e0d8c7cc8d37872","provider":[],"title":"环境"},{"url":"http://store.is.autonavi.com/showpic/f8a487b00d9a21f3c8c5efb52a338d82","provider":[],"title":"环境"}]},{"id":"B0FFGHE7XZ","parent":"B0FFH14DOK","childtype":"202","name":"凯吉利蛋糕&鲜花店(学院路店)","type":"餐饮服务;糕饼店;糕饼店","typecode":"050800","biz_type":"diner","address":"学清路9-9号","location":"116.351200,40.019480","tel":"13522398688;010-62926066;13699261198","distance":"56","biz_ext":{"rating":"3.5","cost":"84.00","meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/2f5e097016f520cd9e1bed839a98a261","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/8e63bd5cae5708321d01fad2a3ed7830","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/65c22625d7e06c7fd186d7eb0ab9b579","provider":[],"title":[]}]},{"id":"B0FFFALV6S","parent":"B0FFH14DOK","childtype":"202","name":"垦荒人(学清路店)","type":"餐饮服务;中餐厅;中餐厅","typecode":"050100","biz_type":"diner","address":"学清路9-8号","location":"116.351364,40.019569","tel":[],"distance":"60","biz_ext":{"rating":"1.0","cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/74bb357e3945ceea13e0cba4b3bb04c5","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/53aa3f0fa3106c892e6dc2dd","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/53aa3f0fa3106c892e6dc2db","provider":[],"title":[]}]},{"id":"B0FFGNMPOQ","parent":[],"childtype":[],"name":"快餐盖饭","type":"餐饮服务;中餐厅;中餐厅","typecode":"050100","biz_type":"diner","address":"双清路1号院内21号楼1层103、105、106室","location":"116.351359,40.019541","tel":"13261259095","distance":"62","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFIXDG1Z","parent":[],"childtype":[],"name":"主食厨房","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号北京培黎职业学院","location":"116.347388,40.020733","tel":"13051095188","distance":"304","biz_ext":{"rating":"3.5","cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/393e14d59b4947c1d8af9be3b78fe85c","provider":[],"title":"火山石烤肠"},{"url":"http://store.is.autonavi.com/showpic/d4cc9b084abc0816c9bdebf57a2f137a","provider":[],"title":"玉米"},{"url":"http://store.is.autonavi.com/showpic/7cbd470ef8c0f6437834957e9a6c9715","provider":[],"title":"特色方便面"}]},{"id":"B0FFHX6UGL","parent":[],"childtype":[],"name":"韩国料理","type":"餐饮服务;外国餐厅;外国餐厅","typecode":"050200","biz_type":"diner","address":"双清路1号院22号楼2层南侧(培黎职业学院大门口北侧二楼)","location":"116.347351,40.020802","tel":"010-62310011;15811176770","distance":"309","biz_ext":{"rating":"4.5","cost":"76.00","meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/87d0d8efbbceda5f1bb4dd43888bd355","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/455d25ed3defbe4331c65580a9c62de2","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/e4bf585c1b89e1978be11a75a30ac04a","provider":[],"title":[]}]},{"id":"B0FFKT8MW5","parent":[],"childtype":[],"name":"名品客咖喱煲仔饭","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号培黎职业学院食堂2号楼","location":"116.347226,40.020748","tel":[],"distance":"317","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFKSD1TB","parent":[],"childtype":[],"name":"粥吧原味豆浆","type":"餐饮服务;中餐厅;特色/地方风味餐厅","typecode":"050118","biz_type":"diner","address":"双清路1号培黎职业学院食堂2号楼","location":"116.347226,40.020748","tel":[],"distance":"317","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFKSCTT9","parent":[],"childtype":[],"name":"沸腾水煮鱼(培黎)","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号培黎职业学院食堂2号楼1层","location":"116.347226,40.020748","tel":[],"distance":"317","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFKQOO4Q","parent":[],"childtype":[],"name":"煎饼果子超市","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号培黎职业学院食堂1号楼一层小卖部","location":"116.347226,40.020748","tel":[],"distance":"317","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFKQ01J5","parent":[],"childtype":[],"name":"美味炒菜饮料","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号培黎职业学院食堂一楼","location":"116.347226,40.020748","tel":[],"distance":"317","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFKMUL8K","parent":[],"childtype":[],"name":"酱汁鱼煲仔饭(培黎)","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号培黎职业学院食堂2号楼二层","location":"116.347226,40.020748","tel":[],"distance":"317","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFIG0FBA","parent":[],"childtype":[],"name":"焖锅汤锅(培黎)","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号培黎职业学院食堂2号楼二层","location":"116.347226,40.020748","tel":"13717981391","distance":"317","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFIJR43K","parent":[],"childtype":[],"name":"中式汉堡屋","type":"餐饮服务;外国餐厅;西餐厅(综合风味)","typecode":"050201","biz_type":"diner","address":"双清路1号院","location":"116.347363,40.021152","tel":[],"distance":"323","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFH7TNCL","parent":[],"childtype":[],"name":"拾贰食","type":"餐饮服务;中餐厅;中餐厅","typecode":"050100","biz_type":"diner","address":"双清路1号培黎职业学院21号楼205","location":"116.347474,40.021337","tel":"010-62842870;13011836113","distance":"325","biz_ext":{"rating":"3.5","cost":"49.00","meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/d60ab50ac627d923866a39ea1d5a10bf","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/226a06f2a6847db587a9bafdad05db2f","provider":[],"title":"秘制红烧肉"},{"url":"http://store.is.autonavi.com/showpic/abb6d588078f25686f48a3cc7ac46fa7","provider":[],"title":"黄豆炖肉"}]},{"id":"B0FFHZGFBN","parent":[],"childtype":[],"name":"锦江之星清华东门店心连星茶餐厅","type":"餐饮服务;中餐厅;中餐厅","typecode":"050100","biz_type":"diner","address":"双清路1号2号楼锦江之星酒店1层(培黎职业学校)","location":"116.346758,40.019747","tel":"010-62955757;18311415687","distance":"342","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFIY9NTM","parent":[],"childtype":[],"name":"培黎烤肉饭","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号北京培黎职业学院内","location":"116.345600,40.020942","tel":[],"distance":"456","biz_ext":{"rating":"3.5","cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/ae623800b6f2fb4f98aa48f0c3b13c36","provider":[],"title":"门头照"},{"url":"http://store.is.autonavi.com/showpic/74e84fed50f9f093dd9a0568387c8a0c","provider":[],"title":"门头照"},{"url":"http://store.is.autonavi.com/showpic/fe4025066e96043b5235ef0413ac9917","provider":[],"title":"门头照"}]},{"id":"B0FFKVZA1S","parent":[],"childtype":[],"name":"酸菜鱼米饭(培黎食堂二楼)","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号培黎职业学院二层食堂酸菜鱼米饭","location":"116.345581,40.020916","tel":[],"distance":"457","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFJCP5GX","parent":[],"childtype":[],"name":"名缘米粉","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"培黎学院","location":"116.345314,40.020822","tel":"18210434740","distance":"477","biz_ext":{"rating":"3.5","cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/0ebeb9c4d8ba4f63671e65dc1ee56356","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/6779514916cdfab7c46f3266bc8756e0","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/d91dcc665b0b3eee1fdf4ab78eb27109","provider":[],"title":[]}]},{"id":"B0FFIXJS7X","parent":[],"childtype":[],"name":"逸轩木桶饭","type":"餐饮服务;快餐厅;快餐厅","typecode":"050300","biz_type":"diner","address":"双清路1号北京培黎职业学院内","location":"116.345314,40.020822","tel":"13681333745","distance":"477","biz_ext":{"rating":[],"cost":[],"meal_ordering":"0"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/bf9ad26eaca07e8a6c1d1b95e4fd93e9","provider":[],"title":"门头照"},{"url":"http://store.is.autonavi.com/showpic/e123a8cfd386c619fe983d88124a4923","provider":[],"title":"门头照"}]}],"markers":[{"latitude":40.019714,"longitude":116.350849,"width":22,"height":32,"id":0,"name":"蒸点味道","address":"学清路9号汇智大厦1层102-7室"},{"latitude":40.01948,"longitude":116.3512,"width":22,"height":32,"id":1,"name":"凯吉利蛋糕&鲜花店(学院路店)","address":"学清路9-9号"},{"latitude":40.019569,"longitude":116.351364,"width":22,"height":32,"id":2,"name":"垦荒人(学清路店)","address":"学清路9-8号"},{"latitude":40.019541,"longitude":116.351359,"width":22,"height":32,"id":3,"name":"快餐盖饭","address":"双清路1号院内21号楼1层103、105、106室"},{"latitude":40.020733,"longitude":116.347388,"width":22,"height":32,"id":4,"name":"主食厨房","address":"双清路1号北京培黎职业学院"},{"latitude":40.020802,"longitude":116.347351,"width":22,"height":32,"id":5,"name":"韩国料理","address":"双清路1号院22号楼2层南侧(培黎职业学院大门口北侧二楼)"},{"latitude":40.020748,"longitude":116.347226,"width":22,"height":32,"id":6,"name":"名品客咖喱煲仔饭","address":"双清路1号培黎职业学院食堂2号楼"},{"latitude":40.020748,"longitude":116.347226,"width":22,"height":32,"id":7,"name":"粥吧原味豆浆","address":"双清路1号培黎职业学院食堂2号楼"},{"latitude":40.020748,"longitude":116.347226,"width":22,"height":32,"id":8,"name":"沸腾水煮鱼(培黎)","address":"双清路1号培黎职业学院食堂2号楼1层"},{"latitude":40.020748,"longitude":116.347226,"width":22,"height":32,"id":9,"name":"煎饼果子超市","address":"双清路1号培黎职业学院食堂1号楼一层小卖部"},{"latitude":40.020748,"longitude":116.347226,"width":22,"height":32,"id":10,"name":"美味炒菜饮料","address":"双清路1号培黎职业学院食堂一楼"},{"latitude":40.020748,"longitude":116.347226,"width":22,"height":32,"id":11,"name":"酱汁鱼煲仔饭(培黎)","address":"双清路1号培黎职业学院食堂2号楼二层"},{"latitude":40.020748,"longitude":116.347226,"width":22,"height":32,"id":12,"name":"焖锅汤锅(培黎)","address":"双清路1号培黎职业学院食堂2号楼二层"},{"latitude":40.021152,"longitude":116.347363,"width":22,"height":32,"id":13,"name":"中式汉堡屋","address":"双清路1号院"},{"latitude":40.021337,"longitude":116.347474,"width":22,"height":32,"id":14,"name":"拾贰食","address":"双清路1号培黎职业学院21号楼205"},{"latitude":40.019747,"longitude":116.346758,"width":22,"height":32,"id":15,"name":"锦江之星清华东门店心连星茶餐厅","address":"双清路1号2号楼锦江之星酒店1层(培黎职业学校)"},{"latitude":40.020942,"longitude":116.3456,"width":22,"height":32,"id":16,"name":"培黎烤肉饭","address":"双清路1号北京培黎职业学院内"},{"latitude":40.020916,"longitude":116.345581,"width":22,"height":32,"id":17,"name":"酸菜鱼米饭(培黎食堂二楼)","address":"双清路1号培黎职业学院二层食堂酸菜鱼米饭"},{"latitude":40.020822,"longitude":116.345314,"width":22,"height":32,"id":18,"name":"名缘米粉","address":"培黎学院"},{"latitude":40.020822,"longitude":116.345314,"width":22,"height":32,"id":19,"name":"逸轩木桶饭","address":"双清路1号北京培黎职业学院内"}],"manualDt":["海底捞","胖哥俩","各种火锅"],"num":23},{"key":"Mall","label":"商业","data":[{"id":"B0FFHRQGQM","parent":"B000A8ZHZ4","childtype":"202","name":"瑞森健身工作室(汇智大厦店)","type":"体育休闲服务;运动场馆;健身中心","typecode":"080111","biz_type":[],"address":"学清路9号汇智大厦A座111室底商","location":"116.351345,40.019676","tel":"13552950773;15711466608","distance":"53","biz_ext":{"rating":"5.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/c422f84872f7fe1a1b61c4cdc88bffb1","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/45ee73f43e93571a18fbf6bdb042f1a7","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/d932807c21265155fcf5bf93f14bac65","provider":[],"title":[]}]},{"id":"B000AA0P1G","parent":"B0FFH14DOK","childtype":"202","name":"灵璧石文化会所","type":"购物服务;专卖店;专营店","typecode":"061200","biz_type":[],"address":"学清路9-7号","location":"116.351351,40.019655","tel":[],"distance":"54","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/53aa3f0fa3106c892e6dc2d9","provider":[],"title":[]}]},{"id":"B0FFKQNLNP","parent":"B000A8ZHZ4","childtype":"202","name":"垦荒人北京绿色食品(学清路店)","type":"购物服务;专卖店;专营店","typecode":"061200","biz_type":[],"address":"学清路汇智大厦A座","location":"116.351371,40.019606","tel":[],"distance":"58","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/e126c9aa13a4596a7f5406c4e88cbf7f","provider":[],"title":[]}]},{"id":"B0FFL7H7MP","parent":[],"childtype":[],"name":"水吧培黎(非餐)","type":"购物服务;超级市场;超市","typecode":"060400","biz_type":[],"address":"双清路1号培黎职业学院食堂2号楼二层","location":"116.347226,40.020748","tel":[],"distance":"317","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFHEGF4B","parent":[],"childtype":[],"name":"shop便利店(学清路店)","type":"购物服务;便民商店/便利店;便民商店/便利店","typecode":"060200","biz_type":[],"address":"学清路甲13号六道","location":"116.352274,40.016770","tel":[],"distance":"368","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFILEKLD","parent":"B000A8VNY2","childtype":"202","name":"郎信科技中心","type":"购物服务;家电电子卖场;数码电子","typecode":"060306","biz_type":[],"address":"财富科技中心B座5层","location":"116.353188,40.016308","tel":[],"distance":"447","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFF2FEGI","parent":"B000A8VNY2","childtype":"202","name":"银美雅超市","type":"购物服务;超级市场;超市","typecode":"060400","biz_type":[],"address":"学清路8号科技财富中心B座1层","location":"116.353140,40.016269","tel":[],"distance":"449","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFH9WNEI","parent":[],"childtype":[],"name":"POLYHOME智能家居体验馆","type":"购物服务;家居建材市场;家居建材市场","typecode":"060600","biz_type":[],"address":"学清路8号科技财富中心B座内","location":"116.353153,40.016259","tel":"4000989498","distance":"450","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFJIY0UC","parent":[],"childtype":[],"name":"嫣然花店(中太大厦店)","type":"购物服务;花鸟鱼虫市场;花卉市场","typecode":"060501","biz_type":[],"address":"双清路中太大厦","location":"116.344719,40.019771","tel":[],"distance":"516","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/21b29eedcae8e41462273427999546ec","provider":[],"title":[]}]},{"id":"B0FFG8FYMH","parent":[],"childtype":[],"name":"华宇铭通","type":"购物服务;家电电子卖场;手机销售","typecode":"060305","biz_type":[],"address":"双清路3号中太太大厦6层","location":"116.344736,40.020749","tel":"010-82828147;18310819549","distance":"524","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFLC0MYY","parent":[],"childtype":[],"name":"北京冰雪梦体育","type":"购物服务;专卖店;专营店","typecode":"061200","biz_type":[],"address":"双清路3号中太大厦34011室北京冰雪梦体育","location":"116.344618,40.020264","tel":[],"distance":"526","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFIRWCYR","parent":[],"childtype":[],"name":"7-ELEVEn(月泉路店)","type":"购物服务;便民商店/便利店;7-ELEVEn便利店","typecode":"060201","biz_type":[],"address":"月泉路逸成东苑","location":"116.349533,40.015025","tel":"010-82429048","distance":"550","biz_ext":{"rating":"4.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/a6e7f4d4324df79b4dc776b9d50071f6","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/a79b585f62f1ed6d854462f9e2727a6a","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/d76b2a2bdbba0598f9ea0371397f06b4","provider":[],"title":[]}]},{"id":"B0FFHK62PR","parent":[],"childtype":[],"name":"千机网·品胜配送站(北京清河店)","type":"购物服务;家电电子卖场;家电电子卖场","typecode":"060300","biz_type":[],"address":"青河四街东后街59号","location":"116.350055,40.024963","tel":[],"distance":"569","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFIVWEWU","parent":[],"childtype":[],"name":"电子E栈","type":"购物服务;家电电子卖场;数码电子","typecode":"060306","biz_type":[],"address":"建清园小区9号楼楼下","location":"116.347626,40.015344","tel":[],"distance":"571","biz_ext":{"rating":"0.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFL8VG1Z","parent":"B0FFF52F4X","childtype":"202","name":"美少女成长记","type":"购物服务;个人用品/化妆品店;其它个人用品店","typecode":"061400","biz_type":[],"address":"月泉路9号逸成东苑1号楼5单元602","location":"116.351455,40.014739","tel":"18801479094","distance":"574","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/ba35858bbdec647476b5b5bfb4eeb889","provider":[],"title":[]}]},{"id":"B0FFLA5XJG","parent":[],"childtype":[],"name":"清河四街便利店","type":"购物服务;便民商店/便利店;便民商店/便利店","typecode":"060200","biz_type":[],"address":"清河四街140号","location":"116.347856,40.024549","tel":"15590160375","distance":"576","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/4238bbc0e9cc58ef50167343ed1730c4","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/a472d695b024116f675542569b57b342","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/a56de8398f9dd963e27bd26d87267692","provider":[],"title":[]}]},{"id":"B000A9QQHP","parent":[],"childtype":[],"name":"博林超市(中太大厦西北)","type":"购物服务;便民商店/便利店;便民商店/便利店","typecode":"060200","biz_type":[],"address":"东升双清路1号培黎职业技术学院10号楼","location":"116.343881,40.021289","tel":[],"distance":"608","biz_ext":{"rating":[],"cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[]},{"id":"B0FFG82DZA","parent":"B000A9EEPH","childtype":"202","name":"干鲜果蔬超市","type":"购物服务;综合市场;蔬菜市场","typecode":"060705","biz_type":[],"address":"月泉路建清园南区3号住宅楼1层中间","location":"116.347636,40.014941","tel":"17310323810","distance":"610","biz_ext":{"rating":"3.5","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/fe33b82072e927290cdff720f28a5cd5","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/bcb5b4b07ad555744a51b94790905345","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/a86a72b2453b36bf931100a04310c312","provider":[],"title":[]}]},{"id":"B0FFFAI3CD","parent":[],"childtype":[],"name":"乐都会KTV","type":"体育休闲服务;娱乐场所;KTV","typecode":"080302","biz_type":[],"address":"双清路6号综合楼地下1层(七天连锁酒店东面)","location":"116.346171,40.015607","tel":"010-82429300","distance":"616","biz_ext":{"rating":"4.0","cost":"228.00"},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/99636d9c6ab6699053109d0ecc8f18e1","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/f75d7ea13cdedcf29118f95a52749b9a","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/4b77c771e0aa6b098c793934469f77f2","provider":[],"title":[]}]},{"id":"B0FFKCIDNM","parent":[],"childtype":[],"name":"物美超市(双清路店)","type":"购物服务;超级市场;超市","typecode":"060400","biz_type":[],"address":"双清路6号院1号楼1层南侧","location":"116.346442,40.015421","tel":"4001016016","distance":"618","biz_ext":{"rating":"4.0","cost":[]},"pname":"北京市","cityname":"北京市","adname":"海淀区","importance":[],"shopid":[],"shopinfo":"0","poiweight":[],"photos":[{"url":"http://store.is.autonavi.com/showpic/1a196a849f7b74644a7a87a25c90d837","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/5deeaf1f4f78b34d167085bb3390aa28","provider":[],"title":[]},{"url":"http://store.is.autonavi.com/showpic/e57239fdb5356cfa746f06d0ecfc807a","provider":[],"title":[]}]}],"markers":[{"latitude":40.019676,"longitude":116.351345,"width":22,"height":32,"id":0,"name":"瑞森健身工作室(汇智大厦店)","address":"学清路9号汇智大厦A座111室底商"},{"latitude":40.019655,"longitude":116.351351,"width":22,"height":32,"id":1,"name":"灵璧石文化会所","address":"学清路9-7号"},{"latitude":40.019606,"longitude":116.351371,"width":22,"height":32,"id":2,"name":"垦荒人北京绿色食品(学清路店)","address":"学清路汇智大厦A座"},{"latitude":40.020748,"longitude":116.347226,"width":22,"height":32,"id":3,"name":"水吧培黎(非餐)","address":"双清路1号培黎职业学院食堂2号楼二层"},{"latitude":40.01677,"longitude":116.352274,"width":22,"height":32,"id":4,"name":"shop便利店(学清路店)","address":"学清路甲13号六道"},{"latitude":40.016308,"longitude":116.353188,"width":22,"height":32,"id":5,"name":"郎信科技中心","address":"财富科技中心B座5层"},{"latitude":40.016269,"longitude":116.35314,"width":22,"height":32,"id":6,"name":"银美雅超市","address":"学清路8号科技财富中心B座1层"},{"latitude":40.016259,"longitude":116.353153,"width":22,"height":32,"id":7,"name":"POLYHOME智能家居体验馆","address":"学清路8号科技财富中心B座内"},{"latitude":40.019771,"longitude":116.344719,"width":22,"height":32,"id":8,"name":"嫣然花店(中太大厦店)","address":"双清路中太大厦"},{"latitude":40.020749,"longitude":116.344736,"width":22,"height":32,"id":9,"name":"华宇铭通","address":"双清路3号中太太大厦6层"},{"latitude":40.020264,"longitude":116.344618,"width":22,"height":32,"id":10,"name":"北京冰雪梦体育","address":"双清路3号中太大厦34011室北京冰雪梦体育"},{"latitude":40.015025,"longitude":116.349533,"width":22,"height":32,"id":11,"name":"7-ELEVEn(月泉路店)","address":"月泉路逸成东苑"},{"latitude":40.024963,"longitude":116.350055,"width":22,"height":32,"id":12,"name":"千机网·品胜配送站(北京清河店)","address":"青河四街东后街59号"},{"latitude":40.015344,"longitude":116.347626,"width":22,"height":32,"id":13,"name":"电子E栈","address":"建清园小区9号楼楼下"},{"latitude":40.014739,"longitude":116.351455,"width":22,"height":32,"id":14,"name":"美少女成长记","address":"月泉路9号逸成东苑1号楼5单元602"},{"latitude":40.024549,"longitude":116.347856,"width":22,"height":32,"id":15,"name":"清河四街便利店","address":"清河四街140号"},{"latitude":40.021289,"longitude":116.343881,"width":22,"height":32,"id":16,"name":"博林超市(中太大厦西北)","address":"东升双清路1号培黎职业技术学院10号楼"},{"latitude":40.014941,"longitude":116.347636,"width":22,"height":32,"id":17,"name":"干鲜果蔬超市","address":"月泉路建清园南区3号住宅楼1层中间"},{"latitude":40.015607,"longitude":116.346171,"width":22,"height":32,"id":18,"name":"乐都会KTV","address":"双清路6号综合楼地下1层(七天连锁酒店东面)"},{"latitude":40.015421,"longitude":116.346442,"width":22,"height":32,"id":19,"name":"物美超市(双清路店)","address":"双清路6号院1号楼1层南侧"}],"manualDt":["大洋百货","弘阳广场","万达广场"],"num":23}]`,
    }

    return (
      <Block>
        <View className="section circum">
          <View className="section-head">
            <Text className="section-head__title">位置及周边配套</Text>
          </View>
        </View>
        <Around building={building} onAction={this.openMap.bind(this)}></Around>
      </Block>
    )
  }

  renderConsuler () {
    const { userInfo: { person: { phone } } } = this.props
    const { projectDetail: { consultants = [] } } = this.props
    return (
      <Block>
        {
          consultants.length > 0 && (
            <View className="section counselor">
              <View className="section-head">
                <Text className="section-head__title">推荐经纪人</Text>
                <View className="section-head__more" onClick={() => { this.handleMoreClick() }}>
                  更多<Text className="iconfont icon-more"></Text>
                </View>
              </View>
              <View className="section-content">
                {
                  consultants.slice(0, 3).map(item => (
                    <View className="item" key={item.id} onClick={this.handleConsuItemClick.bind(this, item)}>
                      <View className="flex">
                        <Image className="avatar" mode="aspectFill" src={getThumbnail(item.photo || item.avatar)}></Image>
                        <View className='name-txt'>
                          <Text className="name">{item.userName}</Text>
                          <Text className='txt'>{item.description || ' '}</Text>
                        </View>

                      </View>
                      <View className="flex item-btn__box">

                        {
                          phone ? (
                            <Button className="item-btn chat" onClick={this.handleChatClick.bind(this, item)}>
                              <Image className='chat-img' src={require('@assets/person/zixun.png')}></Image>
                            </Button>
                          ) : (
                              <Button className="item-btn chat" onClick={this.handleStopPropagation} open-type="getPhoneNumber" onGetphonenumber={(e) => { this.getPhoneNumber(e, item) }}>
                                <Image className='chat-img' src={require('@assets/person/zixun.png')}></Image>
                              </Button>
                            )
                        }
                        <Button className="item-btn tel" onClick={this.handleTelClick.bind(this, item)}>
                          <Image className='dianhua1-img' src={require('@assets/person/dianhua.png')}></Image>
                        </Button>
                      </View>
                    </View>
                  ))
                }
              </View>
            </View>
          )
        }
      </Block>
    )
  }

  renderStatement () {
    return (
      <View className='statement'>
        免责条款：以上价格仅供参考，具体一房一价的信息以售楼处展示为准。本网显示房屋位置、交通、医疗、教育、商业等配套信息，来源于第三方网络数据，不作为要约，仅供参考，双方具体权利义务应以法律规定及买卖合同约定为准。<br></br>本平台对项目周边文化教育的介绍旨在提供相关信息，并不意味着信息发布方对就学安排作出承诺。相关教育资源就学信息存在调整的可能，应以政府教育主管部门及办学颁布的政策规定为准。
      </View>
    )
  }


  renderHelp () {
    const { helpList } = this.state
    return (
      <Block>
        {helpList.length > 0 &&
          <View className="activity">
            <View className="title">助力活动</View>
            <View style={{ position: 'relative' }}>
              <HelpGroupBanner
                style={{ height: '130px' }}
                indicatorDots={false}
                list={helpList}
                onClick={this.handleHelpClick}>
              </HelpGroupBanner>
            </View>
          </View>
        }
      </Block>
    )
  }

  handleHelpClick (item) {
    Taro.navigateTo({
      url: '/pages/activity/detail/assistance?id=' + item.activityId
    })
  }
  handleGroupClick (item) {
    Taro.navigateTo({
      url: '/pages/activity/detail/assemble?id=' + item.activityId
    })
  }
  renderGroup () {
    const { groupList } = this.state
    return (
      <Block>
        {groupList.length > 0 &&
          <View className="activity">
            <View className="title">拼团活动</View>
            <View
              style={{ position: 'relative' }}>
              <HelpGroupBanner
                style={{ height: '130px' }}
                indicatorDots={false}
                list={groupList}
                onClick={this.handleGroupClick}>
              </HelpGroupBanner>
            </View>
          </View>
        }
      </Block>
    )
  }

  renderHouseTypeList () {
    const { statusOpts } = this.state
    const { projectDetail: { buildingApartment } } = this.props
    const list = buildingApartment.filter(item => item.apartmentType === 'apart')
    let imgUrls = list.reduce((prev, cur) => {
      prev = prev.concat(cur.buildingImgList)
      return prev
    }, [])
    imgUrls = imgUrls.map(item => item.url)
    return (
      <Block>
        {
          list.length > 0 && (
            <View className='house-type'>
              <View className='house-type__title'>户型介绍({list.length})</View>
              <ScrollView scrollX>

                <View className='house-type__list'>
                  {list.map(item => (
                    <View className='item' key={item.apartmentId}>
                      {
                        item && (
                          <View className='house__img-info'>
                            <Image className='house__img' src={getThumbnail(item.buildingImgList[0].url)} mode="widthFix" onClick={this.handlePreviewHxImage.bind(this, item.buildingImgList[0].url, imgUrls)}></Image>
                            <View className='house-type__state'>{statusOpts[item.marketStatus - 1]}</View>
                          </View>
                        )
                      }
                      <View className="rest-info">
                        <View className='house-type__name'><Text style="color:#FA5431;margin-right:10px">{item.buildingArea || ''}</Text>{item.apartmentName || ''}</View>
                        <View className='construction__area'>
                          <Text>建面{item.buildingArea || ''}m²</Text>
                          {
                            item.insideArea ? <Text>套内{item.insideArea}m²</Text> : <Text>套内待定</Text>
                          }
                        </View>
                      </View>
                    </View>
                  ))}
                </View>
              </ScrollView>
            </View>
          )
        }
      </Block>

    )
  }
  renderActivities () {
    const { activityList } = this.state
    return (
      <Block>
        {
          activityList.length > 0 && (
            <View className="house-type">
              <View className="section-head">
                <Text className="section-head__title">热门活动</Text>
                <View className="section-head__more" onClick={this.handleActivityMoreClick}>
                  更多活动<Text className="iconfont icon-more"></Text>
                </View>
              </View>
              <ScrollView scrollX>
                <View className="house-type__list" style="margin-top:10px">
                  {
                    activityList.map(item => (
                      <View className="news-item" key={item.dynamicId} onClick={this.handActivityItemClick.bind(this, item.dynamicId)}>
                        <Image mode="aspectFill" src={getThumbnail(item.imgUrl)} className="news-item__pic"></Image>
                        <View className="news-item__title">{item.title}</View>
                      </View>
                    ))
                  }
                </View>
              </ScrollView>
            </View>
          )
        }
      </Block>
    )
  }
  renderNews () {
    const { newsList } = this.state
    return (
      <Block>
        {
          newsList.length > 0 && (
            <View className="house-type">
              <View className="section-head">
                <Text className="section-head__title">新鲜资讯</Text>
                <View className="section-head__more" onClick={this.handleNewsMoreClick}>
                  更多资讯<Text className="iconfont icon-more"></Text>
                </View>
              </View>
              <ScrollView scrollX>
                <View className="house-type__list" style="margin-top:10px">
                  {
                    newsList.map(item => (
                      <View className="news-item" key={item.newsId} onClick={this.handNewsItemClick.bind(this, item.newsId)}>
                        <Image src={getThumbnail(item.newsImg)} mode="aspectFill" className="news-item__pic"></Image>
                        <View className="news-item__title">{item.newsName}</View>
                      </View>
                    ))
                  }
                </View>
              </ScrollView>
            </View>
          )
        }
      </Block>
    )
  }

  renderVideo () {
    console.log('-------props------', this.props)
    const { projectDetail } = this.props
    return (
      <View
        className="pro__banner"
      >
        { console.log('-------projectDetail.videoUrl------', projectDetail.videoUrl)}
        <Video
          src={projectDetail.videoUrl}
          // src='http://wxsnsdy.tc.qq.com/105/20210/snsdyvideodownload?filekey=30280201010421301f0201690402534804102ca905ce620b1241b726bc41dcff44e00204012882540400&bizid=1023&hy=SH&fileparam=302c020101042530230204136ffd93020457e3c4ff02024ef202031e8d7f02030f42400204045a320a0201000400'
          // poster='http://misc.aotu.io/booxood/mobile-video/cover_900x500.jpg'  
          initial-time='0.01'
          style={{
            height: '278px',
            width: '375px'
          }}
          show-mute-btn='true'
        ></Video>
      </View>
    )
  }

  changeCurrent (current) {
    // console.log('value:', current)
    this.setState({
      current: current + 1
    })
  }



  render () {
    const { posterStatus, posterData, loaded, btnstate } = this.state
    const { projectDetail } = this.props
    const { uvList = {} } = projectDetail
    const { total = 0, records = [] } = uvList
    const openDate = projectDetail.openingDate ? dayjs(projectDetail.openingDate).locale('zh-cn').format('YYYY年M月D日') : '暂无'

    // if (projectDetail.videoUrl != null){
    //   setState({ btnstate: 1 }
    // },

    return (
      <Block>
        {
          loaded && (
            <View className='detail'>
              <Notice></Notice>
              {(projectDetail.videoUrl == null || btnstate === 0) && (
                <View
                  className="pro__banner"
                  onClick={this.previewImage.bind(this, projectDetail.buildingImg)}>
                  <Banner
                    list={projectDetail.buildingImg}
                    indicatorDots={false}
                    // current
                    onChange={this.changeCurrent.bind(this)}
                    style={{
                      height: '278px'
                    }}

                  ></Banner>
                  <Text className="pro__banner-text">{this.current}/{(projectDetail.buildingImg && projectDetail.buildingImg.length) || 0}</Text>
                </View>
              )}

              {btnstate === 1 && projectDetail.videoUrl != null &&  this.renderVideo()}

              }
              {btnstate === 1 && projectDetail.videoUrl != null && (<View className='media-btn'>
                <View className='video-btn'  style={{ background: ' rgba(187, 156, 121, 1)', color: 'rgba(255, 255, 255, 1)' }} >视频</View>
                <View className='img-btn' onClick={() => this.setState({ btnstate: 0 })}>图片</View>
              </View>)}

              {btnstate === 0 && projectDetail.videoUrl != null && (<View className='media-btn'>
                <View className='video-btn' onClick={() => this.setState({ btnstate: 1 })} >视频</View>
                <View className='img-btn'  style={{ background: ' rgba(187, 156, 121, 1)', color: 'rgba(255, 255, 255, 1)' }}>图片</View>
              </View>)}


              <ScrollView
                enableBackToTop
                className="wrap"
                scrollY>
                <View className='detail__main'>

                  {/* 详情 */}
                  <View className='base-info'>
                    <View className='project__infor'>
                      <View className='row project__title'>
                        <Text className="bold">{projectDetail.buildingName}</Text>
                        <View className="favor-btn" onClick={this.handleFavor}>
                          <Text className={`iconfont ${isSaved ? 'icon-shoucang saved' : 'icon-shoucang1'}`}></Text>
                          <Text className="txt">收藏</Text>
                        </View>
                      </View>
                      {/* <View className='row project__price'><Text style={{ paddingRight: '20px' }}>均价</Text><Text className="num">{projectDetail.price}</Text></View> */}
                      <View className='row project__tags'>
                        {projectDetail.buildingTag.map(item => <Text className='tag' key={item.tagId}>{item.tagName}</Text>)}
                      </View>
                      {/* 产品类型介绍 */}

                      {this.renderBuildingProjectTypeList()}

                      <View className='row project__addr'>
                        <Text className="label">楼盘地址：</Text>
                        <View className='address'>
                          <Text className="address__text">{projectDetail.address}</Text>
                          {/* <Text className='iconfont icon-jingzhundaohang-copy' onClick={this.openMap.bind(this)}></Text> */}
                        </View>
                      </View>

                      <View className='row project__time'>
                        <Text className="label">开盘时间：</Text>
                        <Text>{openDate}</Text>
                      </View>
                      <View className='row project__time'>
                        <Text className="label">物业：</Text>
                        <Text>{projectDetail.serviceCompany || '暂无'}</Text>
                      </View>

                      {/* <View className='row project__area'>
                        <Text className="label">销售状态：</Text>
                        <Text className="status">{projectDetail.marketStatus}</Text>
                      </View> */}
                      <View className='row-info'>
                        <View className='row'>
                          <Text className="label">车位比率：</Text>{projectDetail.parkingRate || '暂无'}</View>
                        <View className='row'>
                          <Text className="label">容积率：</Text>{projectDetail.volumeRate || '暂无'}</View>
                      </View>
                      <View className='row-info'>

                        <View className='row'>
                          <Text className="label">规划户数：</Text>{projectDetail.familyNum || '暂无'}</View>
                        <View className='row'>
                          <Text className="label">绿化率：</Text>{projectDetail.greeningRate || '暂无'}</View>
                      </View>
                      <View className='row-info'>
                        <View className='row'>
                          <Text className="label">物业费：</Text>{projectDetail.serviceFee || '暂无'}</View>
                      </View>


                      {/* <View className='row'>
                        <Text className="label">装修标准：</Text>{projectDetail.decoration || '暂无'}
                      </View> */}


                      {/* 围观人数 */}
                      <View className='watch__people__num'>
                        <View className='top__txt'>{total}人围观</View>
                        <View className='bottom__img' onClick={this.onViewFans.bind(this)}>
                          <View className="records">
                            {records.slice(0, 9).map(item => <Image src={item.photoOravatar} className='user__img' key={item.personId} />)}
                            {records.length > 9 && <Text> ···</Text>}
                          </View>

                          <Text className="iconfont icon-more"></Text>
                        </View>
                      </View>
                      <View className='more-btn' onClick={this.moreFloor}>更多楼盘信息</View>
                    </View>
                  </View>

                  {/* 项目顾问 */}
                  {this.renderConsuler()}

                  {/* 周边 */}
                  {this.rendercircum()}

                  {/* 户型介绍 */}
                  {this.renderHouseTypeList()}

                  {/* 助力活动 */}
                  {this.renderHelp()}

                  {/* 拼团活动 */}
                  {this.renderGroup()}

                  {/* 新鲜资讯 */}
                  {this.renderNews()}

                  {/* 热门活动 */}
                  {this.renderActivities()}

                  {/* 相册 */}
                  {this.renderPhotoAlbum()}

                  {/* 免责声明 */}
                  {this.renderStatement()}
                </View>
              </ScrollView>

              {/* 生成海报 */}
              {
                posterStatus && (<Poster data={posterData} toggle={this.togglePosterStatus}></Poster>)
              }

              {/* 底部菜单 */}
              {this.renderBottomMenu()}

              {/* <View className="tel-entrance" onClick={this.makePhoneCall}>
                <Text className="iconfont icon-dianhua2"></Text>
                <Text className="text">电话</Text>
              </View> */}
              {/* <View className="home-entrance" onClick={this.toHome}>
                <Text className="iconfont icon-shouyeshouye"></Text>
                <Text className="text">首页</Text>
              </View> */}
              <BackHomeBtn></BackHomeBtn>
            </View>
          )
        }
      </Block>
    );
  }
}
